ExecuteCommand class

Command to execute code strings (-e flag)

Inheritance

Constructors

ExecuteCommand(String code, List<String> originalArgs)

Properties

aliases List<String>
Alternative names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
bridge LuaLike
Get the global LuaLike bridge instance
no setterinherited
category String
The command's category.
no setterinherited
code String
final
description String
A description of this command, included in usage.
no setteroverride
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
io → Console
Access to the I/O helper for console output.
no setterinherited
name String
The name of this command.
no setteroverride
namespaceSeparator String
Separator used to group subcommands for display.
no setterinherited
originalArgs List<String>
final
parent → Command?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command command) → void
Adds Command as a subcommand of this.
inherited
alert(Object message, {Verbosity? verbosity}) → void
Writes an alert box (Laravel-style).
inherited
comment(Object message, {Verbosity? verbosity}) → void
Writes a comment message (Laravel-style).
inherited
error(Object message, {Verbosity? verbosity}) → void
Writes an error message (Laravel-style).
inherited
formatUsage({bool includeDescription = true}) String
Formats help output for this command.
inherited
handleLuaInit() Future<void>
Handle LUA_INIT environment variable
inherited
info(Object message, {Verbosity? verbosity}) → void
Writes an info message (Laravel-style).
inherited
line(Object message, {String? style, Verbosity? verbosity}) → void
Writes a plain line to output (Laravel-style).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the command usage information.
inherited
question(Object message, {Verbosity? verbosity}) → void
Writes a question message (Laravel-style).
inherited
run() Future<void>
Runs this command.
override
safePrint(String message) → void
Safe print function that doesn't flush stdout
inherited
setupArgTable({required List<String> originalArgs, String? scriptPath, List<String> scriptArgs = const [], List<String> codeStrings = const []}) → void
Setup the global arg table following Lua's conventions
inherited
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a usage error with the given message.
inherited
warn(Object message, {Verbosity? verbosity}) → void
Writes a warning message (Laravel-style).
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited