ConsoleOutputDevice class

Implemented types

Constructors

ConsoleOutputDevice(Console console)

Properties

console → Console
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the device is closed
no setteroverride
mode String
The mode this device was opened in (r, w, a, etc.)
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Close the device
override
flush() Future<void>
Flush any buffered data
override
getPosition() Future<int>
Get the current position in the device
override
isEOF() Future<bool>
Check if we're at the end of the device
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read([String format = "l"]) Future<ReadResult>
Read from the device according to the given format format can be:
override
seek(SeekWhence whence, int offset) Future<int>
Seek to a position in the device Returns the new position
override
setBuffering(BufferMode mode, [int? size]) Future<void>
Set the buffering mode and optionally the buffer size
override
toString() String
A string representation of this object.
inherited
write(String data) Future<WriteResult>
Write data to the device
override
writeBytes(List<int> bytes) Future<WriteResult>
Write raw bytes to the device without any encoding.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited