seek method
Seek to a position in the device Returns the new position
Implementation
@override
Future<int> seek(SeekWhence whence, int offset) async {
throw UnimplementedError("ConsoleOutputDevice does not support seek");
}
Seek to a position in the device Returns the new position
@override
Future<int> seek(SeekWhence whence, int offset) async {
throw UnimplementedError("ConsoleOutputDevice does not support seek");
}