DocPageOptions class

Options for rendering the shared LuaLike documentation page shell.

Constructors

DocPageOptions({String title = 'LuaLike API Reference', String brandName = 'LuaLike', String? homeHref, String homeLabel = 'Home'})
Creates shared documentation page options.
const

Properties

brandName String
Sidebar brand text.
final
hashCode int
The hash code for this object.
no setterinherited
homeHref String?
Optional link shown in the sidebar brand row.
final
homeLabel String
Label used for homeHref.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Browser title and top-level page label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited