interpreter property

LuaRuntime? interpreter
getter/setter pair

The runtime currently initializing this library.

LuaLike sets this field before calling registerFunctions. Most custom libraries can access the runtime through LibraryContext.interpreter and do not need to retain this field directly.

Implementation

LuaRuntime? interpreter;