describeValue method

void describeValue(
  1. String name,
  2. ValueDoc doc
)

Registers a ValueDoc describing a constant or typed global value exported by this library.

Use this for scalar constants like math.pi, version strings like _VERSION, or any exported value that is not a function, table, alias, or enum.

Implementation

void describeValue(String name, ValueDoc doc) {
  _library._valueDocs[name] = doc;
}