interpreter property

LuaRuntime? interpreter
final

The interpreter instance that this builtin function belongs to. This is optional for backwards compatibility with existing functions.

Implementation

final LuaRuntime? interpreter;