isOld property
Whether this object belongs to the old generation. Used in generational collection to determine which generation the object belongs to.
Implementation
bool isOld = false;
Whether this object belongs to the old generation. Used in generational collection to determine which generation the object belongs to.
bool isOld = false;