FormatStringParser class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
flags
→ Parser<
String> -
no setter
-
formatStringParser
→ Parser<
List< FormatPart> > -
no setter
-
literalTextParser
→ Parser<
LiteralPart> -
no setter
-
partParser
→ Parser<
FormatPart> -
no setter
-
percent
→ Parser<
String> -
no setter
-
precision
→ Parser<
String> -
no setter
-
specifier
→ Parser<
String> -
no setter
-
specifierParser
→ Parser<
SpecifierPart> -
no setter
-
width
→ Parser<
String> -
no setter
Static Methods
-
escape(
Uint8List bytes) → String - Escapes a byte list according to Lua's %q format rules.
-
parse(
String input) → List< FormatPart> - Parses a format string into a list of FormatPart (literals and specifiers).
-
parseCached(
String input) → List< FormatPart> - Parses and caches format strings, which are often reused in tight loops.