LuaChunkLoadRequest class

Request for loading source or binary chunk input through the active engine.

Constructors

LuaChunkLoadRequest({required Value source, required String chunkName, String mode = 'bt', Value? environment})
const

Properties

chunkName String
final
environment Value?
final
hashCode int
The hash code for this object.
no setterinherited
mode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited