LuaString class

Constructors

LuaString(Uint8List bytes)
LuaString.fromBytes(List<int> b)
factory
LuaString.fromDartString(String s)
factory

Properties

bytes Uint8List
final
hashCode int
The hash code for this object.
no setteroverride
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice(int start, [int? end]) LuaString
toLatin1String() String
Convert to string using Latin-1 interpretation (for Lua string display)
toString() String
A string representation of this object.
override

Operators

operator +(LuaString other) LuaString
operator <(LuaString other) bool
operator <=(LuaString other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(LuaString other) bool
operator >=(LuaString other) bool
operator [](int index) int