LualikeIrControlFlowGraph class final

A control-flow graph derived from a lualike IR prototype.

Properties

blockIndexByPc Map<int, int>
final
blocks List<LualikeIrBasicBlock>
final
dominanceFrontierByBlock Map<int, List<int>>
final
entryBlock LualikeIrBasicBlock
no setter
exitBlocks List<LualikeIrBasicBlock>
no setter
hashCode int
The hash code for this object.
no setterinherited
immediateDominatorByBlock Map<int, int?>
final
prototype LualikeIrPrototype
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blockForPc(int pc) LualikeIrBasicBlock
dominanceFrontierOf(int blockIndex) List<int>
dominates(int dominatorIndex, int dominatedIndex) bool
immediateDominatorOf(int blockIndex) int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited