SpecifierPart class

Inheritance

Constructors

SpecifierPart({required String full, required String flags, String? width, String? precision, required String specifier})

Properties

flags String
final
full String
final
hashCode int
The hash code for this object.
no setterinherited
precision String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specifier String
final
width String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited