WriteResult class

Represents the result of a write operation

Constructors

WriteResult(bool success, [String? error, int? errorCode])

Properties

error String?
final
errorCode int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLua() List<Object?>
Convert to Lua-style error tuple
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited