TableSchema class
Annotates a Dart class to generate a TableDoc for its schema.
The generated code produces a top-level TableDoc constant named
${className}Doc — e.g. PluginInfo -> pluginInfoDoc.
Constructors
- TableSchema({String? name, String? description})
-
const
Properties
- description → String?
-
Description of what this table represents.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Override the Lua table type name. Defaults to the Dart class name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited