DocHtmlResult class
Result of rendering documentation to HTML fragments.
Constructors
- DocHtmlResult({required String sidebar, required String content})
-
Creates rendered HTML fragments for navigation and reference content.
const
Properties
- content → String
-
Main reference markup containing documented library members.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Navigation markup containing library and function links.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited