BuiltinFunctionBuilder class
Builds BuiltinFunction instances bound to a registration context.
Use this when a native function should participate in runtime services such as cached primitive values through BuiltinFunction.primitiveValue.
Constructors
- BuiltinFunctionBuilder(LibraryContext _context)
-
Creates a builder that binds new functions to
_context.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
Object? implementation(List< Object?> args)) → BuiltinFunction - Creates a BuiltinFunction that keeps the active runtime reference.
-
createSimple(
Object? implementation(List< Object?> args)) → Value - Creates a Value-wrapped function without attaching interpreter context.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited