getMetamethods method
Optional metamethods attached to the exported library table.
Override this when the library itself should behave like an object with custom indexing, call behavior, or other metatable-driven operations.
Implementation
Map<String, Function>? getMetamethods(LuaRuntime interpreter) => null;