name property
String
get
name
The public Lua name for this library, such as string or math.
Return an empty string for libraries that should populate the global namespace instead of a namespaced table.
Implementation
String get name;