LibraryRegistrationContext class
Registration context that collects the exported values for a Library.
- Inheritance
-
- Object
- LibraryContext
- LibraryRegistrationContext
Properties
- environment → Environment
-
The environment receiving this library's exported values.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpreter → LuaRuntime?
-
The runtime performing registration.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vm → LuaRuntime?
-
The active runtime, exposed with the legacy
vmname for older code.no setterinherited
Methods
-
define(
String name, dynamic function) → void -
Defines an exported
functionor constant undername. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited