LibraryRegistrationContext class
Registration context that collects the exported values for a Library.
- Inheritance
-
- Object
- LibraryContext
- LibraryRegistrationContext
Properties
- environment → Environment
-
The environment receiving this library's exported values.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interpreter → LuaRuntime?
-
The runtime performing registration.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vm → LuaRuntime?
-
The active runtime, exposed with the legacy
vmname for older code.no setterinherited
Methods
-
define(
String name, Object? descriptorOrValue) → void -
Defines an exported value under
name. -
describe(
String name, FunctionDoc doc) → void -
Attaches documentation metadata to an exported
namewithout the need to create a dedicated BuiltinFunction subclass. -
describeAlias(
String name, AliasDoc doc) → void - Registers an AliasDoc describing a type alias exported by this library.
-
describeEnum(
String name, EnumDoc doc) → void - Registers an EnumDoc describing an enum table exported by this library.
-
describeTable(
String name, TableDoc doc) → void - Registers a TableDoc describing the shape of a Lua table value exported by this library.
-
describeValue(
String name, ValueDoc doc) → void - Registers a ValueDoc describing a constant or typed global value exported by this library.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited