describeEnum method
Registers an EnumDoc describing an enum table exported by this library.
Enums are Lua tables usable at runtime, as opposed to AliasDoc which are compile-time type definitions.
Implementation
void describeEnum(String name, EnumDoc doc) {
_library._enumDocs[name] = doc;
}