AxInstruction class
Instruction using the Ax mode (25-bit unsigned operand).
- Inheritance
-
- Object
- LualikeIrInstruction
- AxInstruction
Constructors
- AxInstruction({required LualikeIrOpcode opcode, required int ax})
-
const
Properties
- ax → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opcode → LualikeIrOpcode
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({R abc(ABCInstruction)?, R abx(ABxInstruction)?, R asbx(AsBxInstruction)?, R ax(AxInstruction)?, R asj(AsJInstruction)?, R avbc(AvBCInstruction)?}) → R -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited