interpreter property
The interpreter instance that this builtin function belongs to. This is optional for backwards compatibility with existing functions.
Implementation
final LuaRuntime? interpreter;
The interpreter instance that this builtin function belongs to. This is optional for backwards compatibility with existing functions.
final LuaRuntime? interpreter;