LuaChunkLoadRequest class
Request for loading source or binary chunk input through the active engine.
Constructors
- LuaChunkLoadRequest({required Value source, required String chunkName, String mode = 'bt', Value? environment})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited